@@ -8,8 +8,7 @@
 #########################################################################
 
 package Term::Clui;
-our $VERSION = '1.74_01';
-$VERSION =~ tr/_//d;
+our $VERSION = '1.72';
 my $stupid_bloody_warning = $VERSION;  # circumvent -w warning
 require Exporter;
 @ISA = qw(Exporter);
@@ -428,7 +427,7 @@ sub ask_filename { my ($question, $default) = @_;  # 1.65 tab-completion
 	}
 	initscr(speakup_silent=>1);
 	endwin();
-	$term = Term::ReadLine->new('ProgramName');
+	$term = new Term::ReadLine 'ProgramName';
 	my $filename = $term->readline($question.' ');   # 1.70
 	print STDERR "\e[J";
 	$filename =~ s/ $//;   # 1.66
@@ -638,7 +637,7 @@ sub choose {  my $question = shift; local @list = @_;  # @list must be local
 			for (; $inew > 0; $inew--) {
 				last unless $icol[$inew];
 				$new_mid_col = $icol[$inew] + 0.5*length($list[$inew]);
-				last if $new_mid_col <= $mid_col;		 # we're past it
+				last if $new_mid_col < $mid_col;		 # we're past it
 				$right_of_target = $new_mid_col - $mid_col;
 			}
 			if (($mid_col - $new_mid_col) > $right_of_target) { $inew++; }
